pub fn validate_desc(bv: &BV, data: &Everything, sc: &mut ScopeContext)Expand description
Validate a complex description, which may be a simple localization key or a block containing
items like triggered_desc or first_valid.
pub fn validate_desc(bv: &BV, data: &Everything, sc: &mut ScopeContext)Validate a complex description, which may be a simple localization key or a block containing
items like triggered_desc or first_valid.