fn validate_desc_map_block(
caller: &str,
block: &Block,
data: &Everything,
sc: &mut ScopeContext,
f: &impl Fn(&Token, &Everything, &mut ScopeContext),
)Expand description
Internal function to recurse over the complex description block logic.
caller is the name of the key that opened this block.
block is the block or sub-block being validated.
sc is the scope in which to evaluate any triggers found.
f is the closure to run over any strings found.